package com.ruoyi.zongzhi.mapper;

import java.util.List;
import com.ruoyi.zongzhi.domain.TcNetworkPingtai;

/**
 * 网络平台Mapper接口
 * 
 * @author ruoyi
 * @date 2023-08-10
 */
public interface TcNetworkPingtaiMapper 
{
    /**
     * 查询网络平台
     * 
     * @param id 网络平台主键
     * @return 网络平台
     */
    public TcNetworkPingtai selectTcNetworkPingtaiById(Long id);

    /**
     * 查询网络平台列表
     * 
     * @param tcNetworkPingtai 网络平台
     * @return 网络平台集合
     */
    public List<TcNetworkPingtai> selectTcNetworkPingtaiList(TcNetworkPingtai tcNetworkPingtai);

    /**
     * 新增网络平台
     * 
     * @param tcNetworkPingtai 网络平台
     * @return 结果
     */
    public int insertTcNetworkPingtai(TcNetworkPingtai tcNetworkPingtai);

    /**
     * 修改网络平台
     * 
     * @param tcNetworkPingtai 网络平台
     * @return 结果
     */
    public int updateTcNetworkPingtai(TcNetworkPingtai tcNetworkPingtai);

    /**
     * 删除网络平台
     * 
     * @param id 网络平台主键
     * @return 结果
     */
    public int deleteTcNetworkPingtaiById(Long id);

    /**
     * 批量删除网络平台
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTcNetworkPingtaiByIds(Long[] ids);
}
