package com.ruoyi.zongzhi.controller;

import java.util.List;
import io.swagger.annotations.Api;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.zongzhi.domain.TcNetworkPingtai;
import com.ruoyi.zongzhi.service.ITcNetworkPingtaiService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 网络平台Controller
 * 
 * @author ruoyi
 * @date 2023-08-10
 */
@RestController
@RequestMapping("/zongzhi/pingtai")
@Api(tags = " 网络平台")
public class TcNetworkPingtaiController extends BaseController
{
    @Autowired
    private ITcNetworkPingtaiService tcNetworkPingtaiService;

    /**
     * 查询网络平台列表
     */

    @GetMapping("/list")
    public TableDataInfo list(TcNetworkPingtai tcNetworkPingtai)
    {
        startPage();
        List<TcNetworkPingtai> list = tcNetworkPingtaiService.selectTcNetworkPingtaiList(tcNetworkPingtai);
        return getDataTable(list);
    }

    /**
     * 导出网络平台列表
     */

    @PostMapping("/export")
    public void export(HttpServletResponse response, TcNetworkPingtai tcNetworkPingtai)
    {
        List<TcNetworkPingtai> list = tcNetworkPingtaiService.selectTcNetworkPingtaiList(tcNetworkPingtai);
        ExcelUtil<TcNetworkPingtai> util = new ExcelUtil<TcNetworkPingtai>(TcNetworkPingtai.class);
        util.exportExcel(response, list, "网络平台数据");
    }

    /**
     * 获取网络平台详细信息
     */

    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcNetworkPingtaiService.selectTcNetworkPingtaiById(id));
    }

    /**
     * 新增网络平台
     */

    @PostMapping
    public AjaxResult add(@RequestBody TcNetworkPingtai tcNetworkPingtai)
    {
        tcNetworkPingtai.setIsStatus(true);
        return toAjax(tcNetworkPingtaiService.insertTcNetworkPingtai(tcNetworkPingtai));
    }

    /**
     * 修改网络平台
     */

    @PutMapping
    public AjaxResult edit(@RequestBody TcNetworkPingtai tcNetworkPingtai)
    {
        return toAjax(tcNetworkPingtaiService.updateTcNetworkPingtai(tcNetworkPingtai));
    }

    /**
     * 删除网络平台
     */

	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcNetworkPingtaiService.deleteTcNetworkPingtaiByIds(ids));
    }
}
